@@ -19,13 +19,18 @@ import re
 from typing import Dict, Sequence, Tuple, Type, Union
 import pkg_resources
 
-import google.api_core.client_options as ClientOptions  # type: ignore
-from google.api_core import exceptions as core_exceptions  # type: ignore
-from google.api_core import gapic_v1  # type: ignore
-from google.api_core import retry as retries  # type: ignore
+from google.api_core.client_options import ClientOptions
+from google.api_core import exceptions as core_exceptions
+from google.api_core import gapic_v1
+from google.api_core import retry as retries
 from google.auth import credentials as ga_credentials  # type: ignore
 from google.oauth2 import service_account  # type: ignore
 
+try:
+    OptionalRetry = Union[retries.Retry, gapic_v1.method._MethodDefault]
+except AttributeError:  # pragma: NO COVER
+    OptionalRetry = Union[retries.Retry, object]  # type: ignore
+
 from google.api_core import operation  # type: ignore
 from google.api_core import operation_async  # type: ignore
 from google.cloud.shell_v1.types import cloudshell
@@ -174,10 +179,10 @@ class CloudShellServiceAsyncClient:
 
     async def get_environment(
         self,
-        request: cloudshell.GetEnvironmentRequest = None,
+        request: Union[cloudshell.GetEnvironmentRequest, dict] = None,
         *,
         name: str = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> cloudshell.Environment:
@@ -185,7 +190,7 @@ class CloudShellServiceAsyncClient:
         not exist.
 
         Args:
-            request (:class:`google.cloud.shell_v1.types.GetEnvironmentRequest`):
+            request (Union[google.cloud.shell_v1.types.GetEnvironmentRequest, dict]):
                 The request object. Request message for
                 [GetEnvironment][google.cloud.shell.v1.CloudShellService.GetEnvironment].
             name (:class:`str`):
@@ -262,9 +267,9 @@ class CloudShellServiceAsyncClient:
 
     async def start_environment(
         self,
-        request: cloudshell.StartEnvironmentRequest = None,
+        request: Union[cloudshell.StartEnvironmentRequest, dict] = None,
         *,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> operation_async.AsyncOperation:
@@ -278,7 +283,7 @@ class CloudShellServiceAsyncClient:
         StartEnvironmentResponse in its response field.
 
         Args:
-            request (:class:`google.cloud.shell_v1.types.StartEnvironmentRequest`):
+            request (Union[google.cloud.shell_v1.types.StartEnvironmentRequest, dict]):
                 The request object. Request message for
                 [StartEnvironment][google.cloud.shell.v1.CloudShellService.StartEnvironment].
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
@@ -329,9 +334,9 @@ class CloudShellServiceAsyncClient:
 
     async def authorize_environment(
         self,
-        request: cloudshell.AuthorizeEnvironmentRequest = None,
+        request: Union[cloudshell.AuthorizeEnvironmentRequest, dict] = None,
         *,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> operation_async.AsyncOperation:
@@ -342,7 +347,7 @@ class CloudShellServiceAsyncClient:
         authenticate.
 
         Args:
-            request (:class:`google.cloud.shell_v1.types.AuthorizeEnvironmentRequest`):
+            request (Union[google.cloud.shell_v1.types.AuthorizeEnvironmentRequest, dict]):
                 The request object. Request message for
                 [AuthorizeEnvironment][google.cloud.shell.v1.CloudShellService.AuthorizeEnvironment].
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
@@ -392,9 +397,9 @@ class CloudShellServiceAsyncClient:
 
     async def add_public_key(
         self,
-        request: cloudshell.AddPublicKeyRequest = None,
+        request: Union[cloudshell.AddPublicKeyRequest, dict] = None,
         *,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> operation_async.AsyncOperation:
@@ -404,7 +409,7 @@ class CloudShellServiceAsyncClient:
         error with ALREADY_EXISTS.
 
         Args:
-            request (:class:`google.cloud.shell_v1.types.AddPublicKeyRequest`):
+            request (Union[google.cloud.shell_v1.types.AddPublicKeyRequest, dict]):
                 The request object. Request message for
                 [AddPublicKey][google.cloud.shell.v1.CloudShellService.AddPublicKey].
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
@@ -456,9 +461,9 @@ class CloudShellServiceAsyncClient:
 
     async def remove_public_key(
         self,
-        request: cloudshell.RemovePublicKeyRequest = None,
+        request: Union[cloudshell.RemovePublicKeyRequest, dict] = None,
         *,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> operation_async.AsyncOperation:
@@ -468,7 +473,7 @@ class CloudShellServiceAsyncClient:
         present, this will error with NOT_FOUND.
 
         Args:
-            request (:class:`google.cloud.shell_v1.types.RemovePublicKeyRequest`):
+            request (Union[google.cloud.shell_v1.types.RemovePublicKeyRequest, dict]):
                 The request object. Request message for
                 [RemovePublicKey][google.cloud.shell.v1.CloudShellService.RemovePublicKey].
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
