@@ -15,7 +15,6 @@
 #
 import os
 import mock
-import packaging.version
 
 import grpc
 from grpc.experimental import aio
@@ -40,9 +39,6 @@ from google.cloud.shell_v1.services.cloud_shell_service import (
 )
 from google.cloud.shell_v1.services.cloud_shell_service import CloudShellServiceClient
 from google.cloud.shell_v1.services.cloud_shell_service import transports
-from google.cloud.shell_v1.services.cloud_shell_service.transports.base import (
-    _GOOGLE_AUTH_VERSION,
-)
 from google.cloud.shell_v1.types import cloudshell
 from google.longrunning import operations_pb2
 from google.oauth2 import service_account
@@ -50,20 +46,6 @@ from google.protobuf import timestamp_pb2  # type: ignore
 import google.auth
 
 
-# TODO(busunkim): Once google-auth >= 1.25.0 is required transitively
-# through google-api-core:
-# - Delete the auth "less than" test cases
-# - Delete these pytest markers (Make the "greater than or equal to" tests the default).
-requires_google_auth_lt_1_25_0 = pytest.mark.skipif(
-    packaging.version.parse(_GOOGLE_AUTH_VERSION) >= packaging.version.parse("1.25.0"),
-    reason="This test requires google-auth < 1.25.0",
-)
-requires_google_auth_gte_1_25_0 = pytest.mark.skipif(
-    packaging.version.parse(_GOOGLE_AUTH_VERSION) < packaging.version.parse("1.25.0"),
-    reason="This test requires google-auth >= 1.25.0",
-)
-
-
 def client_cert_source_callback():
     return b"cert bytes", b"key bytes"
 
@@ -221,7 +203,7 @@ def test_cloud_shell_service_client_client_options(
     options = client_options.ClientOptions(api_endpoint="squid.clam.whelk")
     with mock.patch.object(transport_class, "__init__") as patched:
         patched.return_value = None
-        client = client_class(client_options=options)
+        client = client_class(transport=transport_name, client_options=options)
         patched.assert_called_once_with(
             credentials=None,
             credentials_file=None,
@@ -238,7 +220,7 @@ def test_cloud_shell_service_client_client_options(
     with mock.patch.dict(os.environ, {"GOOGLE_API_USE_MTLS_ENDPOINT": "never"}):
         with mock.patch.object(transport_class, "__init__") as patched:
             patched.return_value = None
-            client = client_class()
+            client = client_class(transport=transport_name)
             patched.assert_called_once_with(
                 credentials=None,
                 credentials_file=None,
@@ -255,7 +237,7 @@ def test_cloud_shell_service_client_client_options(
     with mock.patch.dict(os.environ, {"GOOGLE_API_USE_MTLS_ENDPOINT": "always"}):
         with mock.patch.object(transport_class, "__init__") as patched:
             patched.return_value = None
-            client = client_class()
+            client = client_class(transport=transport_name)
             patched.assert_called_once_with(
                 credentials=None,
                 credentials_file=None,
@@ -271,20 +253,20 @@ def test_cloud_shell_service_client_client_options(
     # unsupported value.
     with mock.patch.dict(os.environ, {"GOOGLE_API_USE_MTLS_ENDPOINT": "Unsupported"}):
         with pytest.raises(MutualTLSChannelError):
-            client = client_class()
+            client = client_class(transport=transport_name)
 
     # Check the case GOOGLE_API_USE_CLIENT_CERTIFICATE has unsupported value.
     with mock.patch.dict(
         os.environ, {"GOOGLE_API_USE_CLIENT_CERTIFICATE": "Unsupported"}
     ):
         with pytest.raises(ValueError):
-            client = client_class()
+            client = client_class(transport=transport_name)
 
     # Check the case quota_project_id is provided
     options = client_options.ClientOptions(quota_project_id="octopus")
     with mock.patch.object(transport_class, "__init__") as patched:
         patched.return_value = None
-        client = client_class(client_options=options)
+        client = client_class(client_options=options, transport=transport_name)
         patched.assert_called_once_with(
             credentials=None,
             credentials_file=None,
@@ -353,7 +335,7 @@ def test_cloud_shell_service_client_mtls_env_auto(
         )
         with mock.patch.object(transport_class, "__init__") as patched:
             patched.return_value = None
-            client = client_class(client_options=options)
+            client = client_class(client_options=options, transport=transport_name)
 
             if use_client_cert_env == "false":
                 expected_client_cert_source = None
@@ -395,7 +377,7 @@ def test_cloud_shell_service_client_mtls_env_auto(
                         expected_client_cert_source = client_cert_source_callback
 
                     patched.return_value = None
-                    client = client_class()
+                    client = client_class(transport=transport_name)
                     patched.assert_called_once_with(
                         credentials=None,
                         credentials_file=None,
@@ -417,7 +399,7 @@ def test_cloud_shell_service_client_mtls_env_auto(
                 return_value=False,
             ):
                 patched.return_value = None
-                client = client_class()
+                client = client_class(transport=transport_name)
                 patched.assert_called_once_with(
                     credentials=None,
                     credentials_file=None,
@@ -448,7 +430,7 @@ def test_cloud_shell_service_client_client_options_scopes(
     options = client_options.ClientOptions(scopes=["1", "2"],)
     with mock.patch.object(transport_class, "__init__") as patched:
         patched.return_value = None
-        client = client_class(client_options=options)
+        client = client_class(client_options=options, transport=transport_name)
         patched.assert_called_once_with(
             credentials=None,
             credentials_file=None,
@@ -479,7 +461,7 @@ def test_cloud_shell_service_client_client_options_credentials_file(
     options = client_options.ClientOptions(credentials_file="credentials.json")
     with mock.patch.object(transport_class, "__init__") as patched:
         patched.return_value = None
-        client = client_class(client_options=options)
+        client = client_class(client_options=options, transport=transport_name)
         patched.assert_called_once_with(
             credentials=None,
             credentials_file="credentials.json",
@@ -512,9 +494,8 @@ def test_cloud_shell_service_client_client_options_from_dict():
         )
 
 
-def test_get_environment(
-    transport: str = "grpc", request_type=cloudshell.GetEnvironmentRequest
-):
+@pytest.mark.parametrize("request_type", [cloudshell.GetEnvironmentRequest, dict,])
+def test_get_environment(request_type, transport: str = "grpc"):
     client = CloudShellServiceClient(
         credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
@@ -557,10 +538,6 @@ def test_get_environment(
     assert response.public_keys == ["public_keys_value"]
 
 
-def test_get_environment_from_dict():
-    test_get_environment(request_type=dict)
-
-
 def test_get_environment_empty_call():
     # This test is a coverage failsafe to make sure that totally empty calls,
     # i.e. request == None and no flattened fields passed, work.
@@ -697,7 +674,9 @@ def test_get_environment_flattened():
         # request object values.
         assert len(call.mock_calls) == 1
         _, args, _ = call.mock_calls[0]
-        assert args[0].name == "name_value"
+        arg = args[0].name
+        mock_val = "name_value"
+        assert arg == mock_val
 
 
 def test_get_environment_flattened_error():
@@ -733,7 +712,9 @@ async def test_get_environment_flattened_async():
         # request object values.
         assert len(call.mock_calls)
         _, args, _ = call.mock_calls[0]
-        assert args[0].name == "name_value"
+        arg = args[0].name
+        mock_val = "name_value"
+        assert arg == mock_val
 
 
 @pytest.mark.asyncio
@@ -750,9 +731,8 @@ async def test_get_environment_flattened_error_async():
         )
 
 
-def test_start_environment(
-    transport: str = "grpc", request_type=cloudshell.StartEnvironmentRequest
-):
+@pytest.mark.parametrize("request_type", [cloudshell.StartEnvironmentRequest, dict,])
+def test_start_environment(request_type, transport: str = "grpc"):
     client = CloudShellServiceClient(
         credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
@@ -778,10 +758,6 @@ def test_start_environment(
     assert isinstance(response, future.Future)
 
 
-def test_start_environment_from_dict():
-    test_start_environment(request_type=dict)
-
-
 def test_start_environment_empty_call():
     # This test is a coverage failsafe to make sure that totally empty calls,
     # i.e. request == None and no flattened fields passed, work.
@@ -892,9 +868,10 @@ async def test_start_environment_field_headers_async():
     assert ("x-goog-request-params", "name=name/value",) in kw["metadata"]
 
 
-def test_authorize_environment(
-    transport: str = "grpc", request_type=cloudshell.AuthorizeEnvironmentRequest
-):
+@pytest.mark.parametrize(
+    "request_type", [cloudshell.AuthorizeEnvironmentRequest, dict,]
+)
+def test_authorize_environment(request_type, transport: str = "grpc"):
     client = CloudShellServiceClient(
         credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
@@ -920,10 +897,6 @@ def test_authorize_environment(
     assert isinstance(response, future.Future)
 
 
-def test_authorize_environment_from_dict():
-    test_authorize_environment(request_type=dict)
-
-
 def test_authorize_environment_empty_call():
     # This test is a coverage failsafe to make sure that totally empty calls,
     # i.e. request == None and no flattened fields passed, work.
@@ -1034,9 +1007,8 @@ async def test_authorize_environment_field_headers_async():
     assert ("x-goog-request-params", "name=name/value",) in kw["metadata"]
 
 
-def test_add_public_key(
-    transport: str = "grpc", request_type=cloudshell.AddPublicKeyRequest
-):
+@pytest.mark.parametrize("request_type", [cloudshell.AddPublicKeyRequest, dict,])
+def test_add_public_key(request_type, transport: str = "grpc"):
     client = CloudShellServiceClient(
         credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
@@ -1060,10 +1032,6 @@ def test_add_public_key(
     assert isinstance(response, future.Future)
 
 
-def test_add_public_key_from_dict():
-    test_add_public_key(request_type=dict)
-
-
 def test_add_public_key_empty_call():
     # This test is a coverage failsafe to make sure that totally empty calls,
     # i.e. request == None and no flattened fields passed, work.
@@ -1166,9 +1134,8 @@ async def test_add_public_key_field_headers_async():
     assert ("x-goog-request-params", "environment=environment/value",) in kw["metadata"]
 
 
-def test_remove_public_key(
-    transport: str = "grpc", request_type=cloudshell.RemovePublicKeyRequest
-):
+@pytest.mark.parametrize("request_type", [cloudshell.RemovePublicKeyRequest, dict,])
+def test_remove_public_key(request_type, transport: str = "grpc"):
     client = CloudShellServiceClient(
         credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
@@ -1194,10 +1161,6 @@ def test_remove_public_key(
     assert isinstance(response, future.Future)
 
 
-def test_remove_public_key_from_dict():
-    test_remove_public_key(request_type=dict)
-
-
 def test_remove_public_key_empty_call():
     # This test is a coverage failsafe to make sure that totally empty calls,
     # i.e. request == None and no flattened fields passed, work.
@@ -1424,7 +1387,6 @@ def test_cloud_shell_service_base_transport():
         transport.operations_client
 
 
-@requires_google_auth_gte_1_25_0
 def test_cloud_shell_service_base_transport_with_credentials_file():
     # Instantiate the base transport with a credentials file
     with mock.patch.object(
@@ -1445,26 +1407,6 @@ def test_cloud_shell_service_base_transport_with_credentials_file():
         )
 
 
-@requires_google_auth_lt_1_25_0
-def test_cloud_shell_service_base_transport_with_credentials_file_old_google_auth():
-    # Instantiate the base transport with a credentials file
-    with mock.patch.object(
-        google.auth, "load_credentials_from_file", autospec=True
-    ) as load_creds, mock.patch(
-        "google.cloud.shell_v1.services.cloud_shell_service.transports.CloudShellServiceTransport._prep_wrapped_messages"
-    ) as Transport:
-        Transport.return_value = None
-        load_creds.return_value = (ga_credentials.AnonymousCredentials(), None)
-        transport = transports.CloudShellServiceTransport(
-            credentials_file="credentials.json", quota_project_id="octopus",
-        )
-        load_creds.assert_called_once_with(
-            "credentials.json",
-            scopes=("https://www.googleapis.com/auth/cloud-platform",),
-            quota_project_id="octopus",
-        )
-
-
 def test_cloud_shell_service_base_transport_with_adc():
     # Test the default credentials are used if credentials and credentials_file are None.
     with mock.patch.object(google.auth, "default", autospec=True) as adc, mock.patch(
@@ -1476,7 +1418,6 @@ def test_cloud_shell_service_base_transport_with_adc():
         adc.assert_called_once()
 
 
-@requires_google_auth_gte_1_25_0
 def test_cloud_shell_service_auth_adc():
     # If no credentials are provided, we should use ADC credentials.
     with mock.patch.object(google.auth, "default", autospec=True) as adc:
@@ -1489,18 +1430,6 @@ def test_cloud_shell_service_auth_adc():
         )
 
 
-@requires_google_auth_lt_1_25_0
-def test_cloud_shell_service_auth_adc_old_google_auth():
-    # If no credentials are provided, we should use ADC credentials.
-    with mock.patch.object(google.auth, "default", autospec=True) as adc:
-        adc.return_value = (ga_credentials.AnonymousCredentials(), None)
-        CloudShellServiceClient()
-        adc.assert_called_once_with(
-            scopes=("https://www.googleapis.com/auth/cloud-platform",),
-            quota_project_id=None,
-        )
-
-
 @pytest.mark.parametrize(
     "transport_class",
     [
@@ -1508,7 +1437,6 @@ def test_cloud_shell_service_auth_adc_old_google_auth():
         transports.CloudShellServiceGrpcAsyncIOTransport,
     ],
 )
-@requires_google_auth_gte_1_25_0
 def test_cloud_shell_service_transport_auth_adc(transport_class):
     # If credentials and host are not provided, the transport class should use
     # ADC credentials.
@@ -1522,26 +1450,6 @@ def test_cloud_shell_service_transport_auth_adc(transport_class):
         )
 
 
-@pytest.mark.parametrize(
-    "transport_class",
-    [
-        transports.CloudShellServiceGrpcTransport,
-        transports.CloudShellServiceGrpcAsyncIOTransport,
-    ],
-)
-@requires_google_auth_lt_1_25_0
-def test_cloud_shell_service_transport_auth_adc_old_google_auth(transport_class):
-    # If credentials and host are not provided, the transport class should use
-    # ADC credentials.
-    with mock.patch.object(google.auth, "default", autospec=True) as adc:
-        adc.return_value = (ga_credentials.AnonymousCredentials(), None)
-        transport_class(quota_project_id="octopus")
-        adc.assert_called_once_with(
-            scopes=("https://www.googleapis.com/auth/cloud-platform",),
-            quota_project_id="octopus",
-        )
-
-
 @pytest.mark.parametrize(
     "transport_class,grpc_helpers",
     [
@@ -1912,7 +1820,7 @@ def test_parse_common_location_path():
     assert expected == actual
 
 
-def test_client_withDEFAULT_CLIENT_INFO():
+def test_client_with_default_client_info():
     client_info = gapic_v1.client_info.ClientInfo()
 
     with mock.patch.object(
